@@ -11,9 +11,9 @@ class QBTKeyboards : public QMap< QString, QMap<QString,QVariant> >
 {
 public:
     QBTKeyboards(QWidget *parent = 0);
-    void reconnect(bool connectedOnly=true);
+    //void reconnect(bool connectedOnly=true);
     QWidget * parent(){return m_parent;};
-    bool reconnectConnectedOnly(){return m_reconnectConnectedOnly;};
+    //bool reconnectConnectedOnly(){return m_reconnectConnectedOnly;};
 
 protected:
     virtual bool enumerateHIDDeviceProperties(bool (*enumFunc)(QBTKeyboards* _this,const QDBusReply< QMap<QString,QVariant> > & properties));
